@@ -36,9 +36,10 @@ class SurveyElement(dict):
         # this node will also have a parent and children, like a tree!
         u"parent": lambda: None,
         u"children": list,
-        u"itemset": dict,
+        u"itemset": unicode,
         u"choice_filter": unicode,
-        }
+        u"autoplay": unicode
+    }
 
     def _default(self):
         # TODO: need way to override question type dictionary
